/*
	PovRay scene that creates Waterman structures based
	upon any geometric primitive. The platonic solids
	are given here but it is easy to modify so that it
	#includes any PovRay model. Note: the geometric model
	will have to be scaled to fit.
	Written and tested using PovRay 3.5
*/

/* Change the next two as desired */
#declare ROOT = 3;
#declare PRIMITIVE = 5 ;
/*
	Current primitive numbers are as follows
	 1 - s sm sphere 	
	 2 - c sm cube
	 3 - 0 sm octahedron
	 4 - i sm icosahedron
	 5 - d sm dodecahedron 
	 6 - r sm rd
	 7 - m sm mecon
	 8 - p sm rectangular prism
	 9 - h sm hex prism 
	 
	 12 - C cube
	 13 - O octahedron
	 14 - I icosahedron
	 15 - D dodecahedron 
	 16 - R rd
	 17 - M mecon
	 18 - P square prism
	 19 - H hex prism 
	 20 - T tetrahedron  
	 21 - t sm tetrahedron
	 31 - s sphere	
	
*/

#declare RADIUS2 = 2 * ROOT;
#declare RADIUS = sqrt(RADIUS2);

#declare vp = 1.5*<3*(RADIUS+0.5),(RADIUS+0.5),(RADIUS+0.5)>;
camera {
   location vp
 
   angle 60   
   sky <0,0,1>
   look_at <0,0,0>  
   rotate <60,-30, 20>
}

global_settings {
  assumed_gamma 1.0
}

light_source {
	<3*RADIUS,RADIUS,2*RADIUS>
	color rgb <1,1,1>
}

#declare IR = int(RADIUS2+1);
#declare ix = -IR;
#while (ix <= IR) 
	#declare iy = -IR;
	#while (iy <= IR)
		#declare iz = -IR;
		#while (iz <= IR)
			#if (mod(ix+iy+iz,2) = 0)
				#if (ix*ix + iy*iy + iz*iz <= RADIUS2)
					#debug "o"
					object {
						#switch (PRIMITIVE)  
						
						
					
						 		
						#case (2)
						        #include "smcube.pov"
							scale 0.5
							#break
						#case (3)
							#include "smoctahedron.pov"
							scale sqrt(2)
							#break
						#case (4)
							#include "smicosahedron.pov"
							scale sqrt(8)
							#break
						#case (5) 
							#include "smdodecahedron.pov"
							scale 1*(1+sqrt(5))/2
							#break    	
						#case (6)
							#include "smrd.pov"
							scale sqrt(4)/2
							#break
						#case (7)
							#include "smmecon.pov"
							scale sqrt(2)
							#break
						#case (8)
							#include "smsquareprism.pov"
							scale sqrt(4) /1
							#break
						#case (9)
							#include "smhexprism.pov"
							scale sqrt(4) /2 
							#break 
						#case (10)
							#include "smtetrahedron.pov"
							scale sqrt(2) 
						
						#case (12)
   						        #include "cube.pov"  							
							scale 1
							#break
						#case (13)
						        #include "octahedron.pov"
							scale sqrt(8) 
							#break
						#case (14)
						        #include "icosahedron.pov"
							scale 2*sqrt(8)
							#break
						#case (15) 
						        #include "dodecahedron.pov"
							scale 2*(1+sqrt(5))/2
							#break   
						#case (16)
							#include "rd.pov"
							scale sqrt(4) / 4
							#break
						#case (17)
							#include "mecon.pov"
							scale sqrt(4) / 1
							#break
						#case (18)
							#include "squareprism.pov"
							scale sqrt(4) /2
							#break
						#case (19)
							#include "hexprism.pov"
							scale sqrt(4)/2
							#break  
						#case (20)
							#include "tetrahedron.pov"
							scale sqrt(2)/3
							#break 
						#case (21)
							#include "smtetrahedron.pov"
							scale sqrt(8)/3
							#break   
						
						#case (31)
							#include "bigsphere.pov"
							scale sqrt(3)/2 	               
						        #break                
						
			
						  		
						#else
							sphere { <0,0,0>, 1 }
							scale 1/sqrt(2.0)  
							
						#end
   					texture {
   					   pigment { 
							#if (ix*ix + iy*iy + iz*iz = RADIUS2)
								color rgb <0.4,0.4,1>
							#else
								color rgb <1.0,0.4,0.4>
							#end
							}
   						finish { 
								specular 0.2
							}
						}
						translate <ix,iy,iz>
					}
				#end
			#end
			#declare iz = iz + 1;
		#end
		#declare iy = iy + 1;
	#end
	#declare ix = ix + 1;
#end

